# Import all of the Facts you want to be made available into this file.

from sales.load import Sales
